# Fingerprint
A [Stylus](https://learnboost.github.com/stylus) plugin to fingerprint images inside your stylesheets, so browsers can re-download them in case it changes before its expiry date or maximum age, because both fingerprint (and so the URL) changes whenever the file does.

### Usage
You can use `Fingerprint` via the `Stylus` Javascript API.

```javascript
var stylus = require('stylus'),
    fingerprint = require('fingerprint');

    stylus(str).use(fingerprint());
```

### Available Options

the `fingerprint` function accepts an object of options with the following keys:

* `strategy`: the strategy method to use, see below for more details;
* `literal`: the literal string to use along the `plain` strategy;
* `paths`: an array of paths to where you store your images - it also uses the included paths on `stylus`;
* `rename`: marks if the fingerprint should rename the filename inside your stylesheets or append the fingerprint to the asset URL.

When using the `rename` option, beware that Fingerprint doesn't move your images around - for now this should be done by some other code, perhaps a part of your deployment script.

The standard behavior is to append the file timestamp to the URL.

### Strategies

* **timestamp** - it uses the mtime of your image. External URLs will be ignore;
* **plain** - uses the provided literal as fingerprint - useful together with sha hashes;
* **md5** - computes the MD5 of the given image.

## License

(The MIT License)

Copyright (c) 2011 Lucas Mazza &lt;luc4smazza@gmail.com&gt;

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
'Software'), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
